struct ObligationStorage<'db> {
overflowed: Vec<Obligation<'db, Predicate<'db>>>,
pending: Vec<(Obligation<'db, Predicate<'db>>, Option<GoalStalledOn<DbInterner<'db>>>)>,
}Fields
overflowed: Vec<Obligation<'db, Predicate<'db>>>Obligations which resulted in an overflow in fulfillment itself.
We cannot eagerly return these as error so we instead store them here
to avoid recomputing them each time try_evaluate_obligations is called.
This also allows us to return the correct FulfillmentError for them.
pending: Vec<(Obligation<'db, Predicate<'db>>, Option<GoalStalledOn<DbInterner<'db>>>)>Implementations
Sourceimpl<'db> ObligationStorage<'db>
impl<'db> ObligationStorage<'db>
fn register( &mut self, obligation: Obligation<'db, Predicate<'db>>, stalled_on: Option<GoalStalledOn<DbInterner<'db>>>, )
fn clone_pending(&self) -> Vec<Obligation<'db, Predicate<'db>>>
fn drain_pending<'this, 'cond>( &'this mut self, cond: impl 'cond + Fn(&Obligation<'db, Predicate<'db>>) -> bool, ) -> impl Iterator<Item = (Obligation<'db, Predicate<'db>>, Option<GoalStalledOn<DbInterner<'db>>>)>
fn on_fulfillment_overflow(&mut self, infcx: &InferCtxt<'db>)